function [c,k,theta,y,yd,i,g,gy,cy,iy,ferror]=MLQ(eps,theta0,k0,css,kss,thetass,nobs,param)

% [Copyright: J. Ruiz]


A=param(1);
beta=param(2);
sigma=param(3);
n=param(4);
delta=param(5);
alpha=param(6);
tauc=param(7);
tauy=param(8);
rho=param(9);
sigmae=param(10);



% linear-quadratic approximation
% first- and second-order numerical derivatives are computed
% the gradient of the utility function is stored in the 3x1 vector MB
% while the hessian is saved in the 3x3 matrix MA

z=[kss,kss,log(thetass)]';
auxi=1e-8*eye(3);
MB=zeros(3,1);
for i=1:3
    MB(i)=(feval('util',z+auxi(:,i),param)-...
        feval('util',z,param))/auxi(i,i);
end

auxi=1e-5*eye(3,3);
MA=zeros(3,3);
for i=1:3
    for j=1:3
        MA(i,j)=(feval('util',z+auxi(:,i)+auxi(:,j),param)-...
            feval('util',z+auxi(:,i),param)-...
            feval('util',z+auxi(:,j),param)+...
            feval('util',z,param))/(auxi(i,i)^2);
    end
end

phi=(MA(1,1)+beta*MA(2,2))/(beta*MA(1,2));
root1=(-phi+(phi^2-4/beta)^0.5)/2;
root2=(-phi-(phi^2-4/beta)^0.5)/2;
    if abs(root1)<1
        lambda1=root1;
    else
        lambda2=root1;
    end

    if abs(root2)<1
        lambda1=root2;
    else
        lambda2=root2;
    end

    k=[];k=[k;k0];
    theta=[];theta=[theta;theta0];

for t=1:nobs
    theta1=exp(rho*log(theta0)+eps(t));
    k1=kss+lambda1*(k0-kss)+((MA(1,3)+beta*rho*MA(2,3))/(beta*MA(1,2)*...
        (lambda2-rho)))*log(theta0);
    theta0=theta1;
    k0=k1;
    k=[k;k0];
    theta=[theta;theta0];
end

c=[];
i=[];
y=[];
g=[];
gy=[];
cy=[];
iy=[];
yd=[];
ferror=[];

for t=1:nobs
    y1=theta(t)*A*(k(t)^alpha);
    c1=(1/(1+tauc))*(-(1+n)*k(t+1)+(1-delta)*k(t)+(1-tauy)*y1);
    i1=(1+n)*k(t+1)-(1-delta)*k(t);
    g1=tauc*c1+tauy*y1;
    yd1=(1-tauy)*y1;
    cy1=c1/y1;
    iy1=i1/y1;
    gy1=g1/y1;
    y=[y;y1];
    c=[c;c1];
    i=[i;i1];
    g=[g;g1];
    yd=[yd;yd1];
    cy=[cy;cy1];
    iy=[iy;iy1];
    gy=[gy;gy1];
end

for t=1:nobs-1;
    ferror1=(c(t+1)^(-sigma))*((1-tauy)*alpha*A*theta(t+1)*...
          (k(t+1)^(alpha-1))+(1-delta))-((1+n)/beta)*(c(t)^(-sigma));
    ferror=[ferror;ferror1];
end

