function f=ss_lsims(x,param)
% This program uses optimality conditions and budget constraint to lay out difference 
% equations describing the dynamics for the discrete-time, stochastic version of the 
% Cass-Koopmans economy. These conditions can be used either to compute steady-state 
% levels of the endogenous variables, or the transition matrix for the log-linear 
% approximation to the model.

% [Copyright: J. Ruiz]



A=param(1);
beta=param(2);
sigma=param(3);
n=param(4);
delta=param(5);
alpha=param(6);
tauc=param(7);
tauy=param(8);
rho=param(9);

lk1=x(1);
lk=x(2);
lc1=x(3);
lc=x(4);
ltheta1=x(5);
ltheta=x(6);
eps=x(7);
xi=x(8);

f(1)=-(1+tauc)*exp(lc)-(1+n)*exp(lk1)+...
    (1-tauy)*exp(ltheta)*A*(exp(alpha*lk))+(1-delta)*exp(lk);
f(2)=-((1+n)/beta)*(exp(-sigma*lc))+((1-delta)+(1-tauy)*alpha*...
    exp(ltheta1)*A*(exp((alpha-1)*lk1)))*(exp(-sigma*lc1))+xi;
f(3)=-ltheta1+rho*ltheta+eps;
f(4)=lc1-lc;
f(5)=lk1-lk;
f(6)=ltheta1-ltheta;
f(7)=eps;
f(8)=xi;
f=f';

