function f=ss_sims(x,param)
% This program uses optimality conditions and budget constraint to lay out difference 
% equations describing the dynamics for the discrete-time, stochastic version of the 
% Cass-Koopmans economy. These conditions can be used either to compute steady-state 
% levels of the endogenous variables, or the transition matrix for the linear 
% approximation to the model.

% [Copyright: J. Ruiz]


A=param(1);
beta=param(2);
sigma=param(3);
n=param(4);
delta=param(5);
alpha=param(6);
tauc=param(7);
tauy=param(8);
rho=param(9);

k1=x(1);
k=x(2);
c1=x(3);
c=x(4);
ltheta1=x(5);
ltheta=x(6);
eps=x(7);
xi=x(8);

f(1)=-(1+tauc)*c-(1+n)*k1+(1-tauy)*exp(ltheta)*A*(k^alpha)+(1-delta)*k;
f(2)=-((1+n)/beta)*(c^(-sigma))+((1-delta)+(1-tauy)*alpha*...
    exp(ltheta1)*A*(k1^(alpha-1)))*(c1^(-sigma))+xi;
f(3)=-ltheta1+rho*ltheta+eps;
f(4)=c1-c;
f(5)=k1-k;
f(6)=ltheta1-ltheta;
f(7)=eps;
f(8)=xi;
f=f';

